import numpy as np


def get_chiral_spg():
    sohncke_class_2_spg = np.array(
        [
            76,
            78,
            91,
            95,
            92,
            96,
            144,
            145,
            151,
            153,
            152,
            154,
            169,
            170,
            171,
            172,
            178,
            179,
            180,
            181,
            212,
            213,
        ]
    )
    sohncke_class_3_spg = np.array(
        [
            1,
            3,
            4,
            5,
            16,
            17,
            18,
            19,
            20,
            21,
            22,
            23,
            24,
            75,
            77,
            79,
            80,
            89,
            90,
            93,
            94,
            97,
            98,
            143,
            146,
            149,
            150,
            155,
            168,
            173,
            177,
            182,
            195,
            196,
            197,
            198,
            199,
            207,
            208,
            209,
            210,
            211,
            214,
        ]
    )
    sohncke_all_spg = np.concatenate([sohncke_class_2_spg, sohncke_class_3_spg])

    return sohncke_all_spg


def is_chiral(spg_number):
    chiral_spg = get_chiral_spg()
    return spg_number in chiral_spg
